@@ -7,7 +7,7 @@ use Moo;
 use Try::Tiny;
 use Test::Deep::NoTest;
 
-our $VERSION="0.02";
+our $VERSION="0.03";
 
 has table       => (is => 'rw', required => 1);
 has hash_key    => (is => 'rw', required => 1);
@@ -24,10 +24,10 @@ sub _build_secret_key { $ENV{AWS_SECRET_KEY} }
 sub _build_dynamodb {
     my $self = shift;
     Net::Amazon::DynamoDB::Lite->new(
-        region     => $self->region,
-        access_key => $self->access_key,
-        secret_key => $self->secret_key,
-        timeout    => $self->timeout,
+        region             => $self->region,
+        access_key         => $self->access_key,
+        secret_key         => $self->secret_key,
+        connection_timeout => $self->timeout,
     );
 }
 
